@@ -1,5 +1,5 @@
 import click
-from download_genesis import *
+from tendermint_chunked_genesis_download import *
 
 
 # printing the errors with red
